@@ -1,7 +1,7 @@
 package Algorithm::RandomizedTreesForBigData;
 
 #--------------------------------------------------------------------------------------
-# Copyright (c) 2016 Avinash Kak. All rights reserved.  This program is free
+# Copyright (c) 2017 Avinash Kak. All rights reserved.  This program is free
 # software.  You may modify and/or distribute it under the same terms as Perl itself.
 # This copyright notice must remain attached to the file.
 #
@@ -9,16 +9,16 @@ package Algorithm::RandomizedTreesForBigData;
 # trees using randomized selection of samples from a large training data file.
 # -------------------------------------------------------------------------------------
 
-use lib 'blib/lib', 'blib/arch';
+#use lib 'blib/lib', 'blib/arch';
 
 #use 5.10.0;
 use strict;
 use warnings;
 use Carp;
 use List::Util qw(pairmap);
-use Algorithm::DecisionTree 3.42;
+use Algorithm::DecisionTree 3.43;
 
-our $VERSION = '3.42';
+our $VERSION = '3.43';
 
 ############################################   Constructor  ##############################################
 sub new { 
@@ -462,11 +462,12 @@ sub check_for_illegal_params {
 sub cleanup_csv {
     my $line = shift;
     $line =~ tr/\/:?()[]{}'/          /;
-    my @double_quoted = substr($line, index($line,',')) =~ /\"[^\"]+\"/g;
+#    my @double_quoted = substr($line, index($line,',')) =~ /\"[^\"]+\"/g;
+    my @double_quoted = substr($line, index($line,',')) =~ /\"[^\"]*\"/g;
     for (@double_quoted) {
         my $item = $_;
         $item = substr($item, 1, -1);
-        $item =~ s/^s+|,|\s+$//g;
+        $item =~ s/^\s+|,|\s+$//g;
         $item = join '_',  split /\s+/, $item;
         substr($line, index($line, $_), length($_)) = $item;
     }
@@ -481,4 +482,5 @@ sub cleanup_csv {
     return $line;
 }
 
+
 1;
